pancakes package
================

Submodules
----------

pancakes.cli module
-------------------

.. automodule:: pancakes.cli
    :members:
    :undoc-members:
    :show-inheritance:

pancakes.pancakes module
------------------------

.. automodule:: pancakes.pancakes
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pancakes
    :members:
    :undoc-members:
    :show-inheritance:
